from fileformats.core import __version__

from .abstract import (
    AbstractFile,
    AbstractSubclass,
    AnotherConcreteClass,
    ConcreteClass,
    ConvertibleToFile,
)
from .basic import Bar, Baz, Foo, Qux
from .classifiers.file import A, B, C, D, E, F, G, H, J, K, L, M, N, P, Q, R, TestField
from .classifiers.generic import Classified, U, V, W, X, Y, Z
from .headers import (
    EncodedText,
    ImageWithHeader,
    MyBinaryFormat,
    MyBinaryFormatX,
    MyFormat,
    MyFormatGz,
    MyFormatGzX,
    MyFormatX,
    MyHeader,
    MyOtherBinaryFormatX,
    SeparateHeader,
    Xyz,
    YFile,
    YourFormat,
    ZFile,
)
from .magic import Magic, MagicVersion

__all__ = [
    "__version__",
    "Foo",
    "Bar",
    "Baz",
    "Qux",
    "YFile",
    "ZFile",
    "Xyz",
    "MyFormat",
    "MyFormatGz",
    "MyFormatGzX",
    "MyFormatX",
    "MyBinaryFormat",
    "MyHeader",
    "MyBinaryFormatX",
    "MyOtherBinaryFormatX",
    "YourFormat",
    "SeparateHeader",
    "ImageWithHeader",
    "EncodedText",
    "A",
    "B",
    "C",
    "D",
    "E",
    "F",
    "G",
    "H",
    "J",
    "K",
    "L",
    "M",
    "N",
    "P",
    "Q",
    "R",
    "TestField",
    "Classified",
    "U",
    "V",
    "W",
    "X",
    "Y",
    "Z",
    "Magic",
    "MagicVersion",
    "AbstractFile",
    "AbstractSubclass",
    "ConcreteClass",
    "AnotherConcreteClass",
    "ConvertibleToFile",
]
